/****************************************************************/
/*            Remove a user from the Weasel database            */
/*                                                              */
/*      Author:       Peter Moylan (peter@ee.newcastle.edu.au)  */
/*      Started:      8 June 2000                               */
/*      Last revised: 23 March 2004                             */
/*                                                              */
/*  Usage:                                                      */
/*         remove username                                      */
/*                                                              */
/*     In the multidomain case, the username should be of the   */
/*     form user@domain.                                        */
/*                                                              */
/*  Installation:                                               */
/*     Put this file in the directory containing WEASEL.INI     */
/*                                                              */
/****************************************************************/

Globals = "MultiDomain MailRoot Domains."
CALL RxFuncAdd SysLoadFuncs, rexxutil, sysloadfuncs
CALL SysLoadFuncs

PARSE ARG username
IF username = '' THEN
    DO
        SAY "Usage: remove username"
        EXIT 0
    END

/* Switch our working directory to the program directory */

PARSE SOURCE rubbish rubbish SrcDir
j = LASTPOS('\', SrcDir)
IF j > 0 THEN SrcDir = LEFT(SrcDir, j-1)
WrkDir = DIRECTORY()
CALL DIRECTORY SrcDir

CALL ParseDomainInfo
IF MultiDomain THEN SAY "Weasel is in multidomain mode"
ELSE SAY "Weasel is in single-domain mode"
CALL RemoveUser username

CALL DIRECTORY WrkDir
EXIT 0

/****************************************************************/
/*                     REMOVING THE USER                        */
/****************************************************************/

RemoveUser: PROCEDURE expose (Globals)

    /* Prerequisite: the global variables MultiDomain, MailRoot */
    /* and Domains. have already been set, for example by       */
    /* calling ParseDomainInfo (see below).                     */

    PARSE ARG username
    PARSE VALUE username WITH user'@'domain
    dom = IdentifyDomain(domain)
    IF MultiDomain & (dom = 0) THEN
        DO
            IF Domains.0 = 0 THEN DO
                IF domain = '' THEN SAY "You don't have any domains defined"
                ELSE SAY "Domain "domain" does not exist"
                SAY "Operation failed"
                RETURN
            END
            ELSE IF domain = '' THEN DO
                SAY "No domain specified, assuming domain "Domains.1
                dom = 1
            END
            ELSE DO
                SAY "Domain "domain" does not exist"
                SAY "Operation failed"
                RETURN
            END
        END /*IF*/
    dir = MailRoot
    IF MultiDomain THEN DO
        dir = dir||Domains.dom||'\'
        INIFile = dir||'DOMAIN.INI'
    END
    ELSE INIFile = 'WEASEL.INI'

    /* Check whether the user already exists in this domain. */

    IF SysIni(INIFile, user, 'Password') = 'ERROR:' THEN
        SAY "Error: user "username" does not exist"
    ELSE
        DO
            CALL SysIni INIFile, user, 'DELETE:'

            /* Have removed the user from the INI file, now try  */
            /* to remove the user's mail directory.              */

            MailDir = dir||user
            SAY 'MailDir is 'MailDir
            IF SysRmDir(MailDir) \= 0 THEN
                DO
                    SAY "Could not remove user's mail directory"
                    SAY "     "MailDir
                    SAY "You should do this manually after checking for unsent mail"
                END

            SAY "User "username" removed"
        END

    RETURN

/****************************************************************/
/*                                                              */
/*       BUILDING THE MAILROOT AND THE LIST OF DOMAINS          */
/*                                                              */
/*  This is an initialisation procedure that sets the global    */
/*  variables MultiDomain, MailRoot, and Domains.  For the      */
/*  purposes of this program those variables have values that   */
/*  never change, so you should call this procedure once, and   */
/*  then call procedure IdentifyDomain (below) as many times    */
/*  as you need to.                                             */
/*                                                              */
/****************************************************************/

ParseDomainInfo: PROCEDURE expose (Globals)

    /* On exit, Domains.0 contains the number of domains we are */
    /* hosting, and the domain names are in Domains.j for j = 1 */
    /* to Domains.0.  In the single-domain case, Domains.0 = 1  */
    /* and Domains.1 is the empty string.                       */

    /* This procedure also sets the global variables 'MailRoot' */
    /* and 'MultiDomain'.                                       */

    /* Figure out the mail root. */

    INIFile = "WEASEL.INI"
    Nul = '00'X
    MailRoot = SysIni(INIFile, '$SYS', 'MailRoot')
    j = POS(Nul,MailRoot)
    IF j > 0 THEN MailRoot = LEFT(MailRoot, j-1)
    MailRoot = TRANSLATE(STRIP(MailRoot), '\', '/')

    MultiDomain = SysIni(INIFile, '$SYS', 'MultiDomainEnabled') == '01'X
    IF MultiDomain THEN DO
        Domains.0 = 0
        DomainString = SysIni(INIFile, '$SYS', 'Domains')

        DO WHILE DomainString \= ""
            PARSE VALUE DomainString WITH current '00'X DomainString
            current = TRANSLATE(STRIP(current))
            IF current \= "" THEN DO
                k = Domains.0 + 1
                Domains.k = current
                Domains.0 = k
            END /*IF*/
        END /*DO FOREVER*/

    END
    ELSE DO
        Domains.0 = 1
        Domains.1 = ''
    END /*IF*/;
    RETURN

/****************************************************************/
/*                    IDENTIFYING A DOMAIN                      */
/****************************************************************/

IdentifyDomain: PROCEDURE expose (Globals)

    /* This procedure is called with a single parameter, which  */
    /* is the 'domain name' part of an e-mail address.  We      */
    /* return an integer k such that the given name is one of   */
    /* the names for Domain.k.  The result k=0 means "no such   */
    /* domain is hosted here".                                  */

    PARSE UPPER ARG name
    singledomain = (Domains.0 = 1) & (Domains.1 = '')
    Nul = '00'X

    success = 0
    DO k = 1 TO Domains.0

        /* We have a match if name matches the domain name. */

        IF name = Domains.k THEN DO
            success = 1
            LEAVE
        END /*IF*/

        /* Otherwise, we have to look up the "Local" list for  */
        /* this domain.                                        */

        IF singledomain THEN
            INIFile = "WEASEL.INI"
        ELSE
            INIFile = MailRoot||Domains.k||"\DOMAIN.INI"

        LocalList = SysIni(INIFile, '$SYS', 'Local')
        j = POS(Nul||Nul, LocalList)
        IF j > 0 THEN LocalList = LEFT(LocalList, j-1)

        DO FOREVER
            IF LocalList = "" THEN LEAVE
            PARSE VALUE LocalList WITH current '00'X LocalList
            current = TRANSLATE(STRIP(current))
            IF name = current THEN DO
                success = 1
                LEAVE
            END /*IF*/
        END /*DO FOREVER*/

        IF success THEN LEAVE

    END /* DO k = 1 TO ... */

    IF \success THEN k = 0

    RETURN k

/****************************************************************/

